==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/outputs/ClassificationJobS3JobDefinitionScopingExcludesAnd.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property simpleScopeTerm A property-based condition that defines a property, operator, and one or more values for including or excluding an object from the job. (documented below)
 * @property tagScopeTerm A tag-based condition that defines the operator and tag keys or tag key and value pairs for including or excluding an object from the job. (documented below)
 */
public data class ClassificationJobS3JobDefinitionScopingExcludesAnd(
    public val simpleScopeTerm: ClassificationJobS3JobDefinitionScopingExcludesAndSimpleScopeTerm? =
        null,
    public val tagScopeTerm: ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTerm? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.macie2.outputs.ClassificationJobS3JobDefinitionScopingExcludesAnd):
            ClassificationJobS3JobDefinitionScopingExcludesAnd =
            ClassificationJobS3JobDefinitionScopingExcludesAnd(
                simpleScopeTerm = javaType.simpleScopeTerm().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionScopingExcludesAndSimpleScopeTerm.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                tagScopeTerm = javaType.tagScopeTerm().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTerm.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/outputs/ClassificationJobS3JobDefinitionScopingExcludesAnd.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property simpleScopeTerm A property-based condition that defines a property, operator, and one or more values for including or excluding an object from the job. (documented below)
 * @property tagScopeTerm A tag-based condition that defines the operator and tag keys or tag key and value pairs for including or excluding an object from the job. (documented below)
 */
public data class ClassificationJobS3JobDefinitionScopingExcludesAnd(
    public val simpleScopeTerm: ClassificationJobS3JobDefinitionScopingExcludesAndSimpleScopeTerm? =
        null,
    public val tagScopeTerm: ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTerm? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.macie2.outputs.ClassificationJobS3JobDefinitionScopingExcludesAnd): ClassificationJobS3JobDefinitionScopingExcludesAnd =
            ClassificationJobS3JobDefinitionScopingExcludesAnd(
                simpleScopeTerm = javaType.simpleScopeTerm().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionScopingExcludesAndSimpleScopeTerm.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                tagScopeTerm = javaType.tagScopeTerm().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTerm.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
